
# -----------------------------------------------------------------------
# KSAP_ATP
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP
/

CREATE TABLE KSAP_ATP
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , END_DT TIMESTAMP
        , NAME VARCHAR(255)
        , START_DT TIMESTAMP
        , STATE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSAP_ATPP1 PRIMARY KEY(ID)


    , INDEX KSAP_ATP_I1 (TYPE)
    , INDEX KSAP_ATP_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_ATTR
/

CREATE TABLE KSAP_ATP_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_ATP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_DUR_TYPE
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_DUR_TYPE
/

CREATE TABLE KSAP_ATP_DUR_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_DUR_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_DUR_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_DUR_TYPE_ATTR
/

CREATE TABLE KSAP_ATP_DUR_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_DUR_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_ATP_DUR_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_SEASONAL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_SEASONAL_TYPE
/

CREATE TABLE KSAP_ATP_SEASONAL_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_SEASONAL_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_SEASONAL_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_SEASONAL_TYPE_ATTR
/

CREATE TABLE KSAP_ATP_SEASONAL_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_SEASONAL_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_ATP_SEAS_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_TYPE
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_TYPE
/

CREATE TABLE KSAP_ATP_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , DUR_TYPE VARCHAR(255)
        , SEASONAL_TYPE VARCHAR(255)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_TYPEP1 PRIMARY KEY(TYPE_KEY)


    , INDEX KSAP_ATP_TYPE_I1 (SEASONAL_TYPE)
    , INDEX KSAP_ATP_TYPE_I2 (DUR_TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_ATP_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_ATP_TYPE_ATTR
/

CREATE TABLE KSAP_ATP_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_ATP_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_ATP_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_DT_RANGE
# -----------------------------------------------------------------------
drop table if exists KSAP_DT_RANGE
/

CREATE TABLE KSAP_DT_RANGE
(
      DATERANGE_KEY VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , END_DT TIMESTAMP
        , NAME VARCHAR(255)
        , START_DT TIMESTAMP
        , STATE VARCHAR(255)
        , ATP_ID VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , DT_RANGE_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSAP_DT_RANGEP1 PRIMARY KEY(DATERANGE_KEY)


    , INDEX KSAP_DT_RANGE_I1 (DT_RANGE_TYPE_ID)
    , INDEX KSAP_DT_RANGE_I2 (RT_DESCR_ID)
    , INDEX KSAP_DT_RANGE_I3 (ATP_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_DT_RANGE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_DT_RANGE_ATTR
/

CREATE TABLE KSAP_DT_RANGE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_DT_RANGE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_DT_RANGE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_DT_RANGE_TYPE
# -----------------------------------------------------------------------
drop table if exists KSAP_DT_RANGE_TYPE
/

CREATE TABLE KSAP_DT_RANGE_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_DT_RANGE_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_DT_RANGE_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_DT_RANGE_TYPE_ATTR
/

CREATE TABLE KSAP_DT_RANGE_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_DT_RANGE_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_DT_RANGE_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_MLSTN
# -----------------------------------------------------------------------
drop table if exists KSAP_MLSTN
/

CREATE TABLE KSAP_MLSTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , MLSTN_DT TIMESTAMP
        , NAME VARCHAR(255)
        , STATE VARCHAR(255)
        , ATP_ID VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , MLSTN_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSAP_MLSTNP1 PRIMARY KEY(ID)


    , INDEX KSAP_MLSTN_I1 (ATP_ID)
    , INDEX KSAP_MLSTN_I2 (RT_DESCR_ID)
    , INDEX KSAP_MLSTN_I3 (MLSTN_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_MLSTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_MLSTN_ATTR
/

CREATE TABLE KSAP_MLSTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_MLSTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_MLSTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_MLSTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSAP_MLSTN_TYPE
/

CREATE TABLE KSAP_MLSTN_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_MLSTN_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_MLSTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSAP_MLSTN_TYPE_ATTR
/

CREATE TABLE KSAP_MLSTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_MLSTN_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSAP_MLSTN_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSAP_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSAP_RICH_TEXT_T
/

CREATE TABLE KSAP_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSAP_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_COMMENT
# -----------------------------------------------------------------------
drop table if exists KSCO_COMMENT
/

CREATE TABLE KSCO_COMMENT
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , STATE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , REFERENCE VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSCO_COMMENTP1 PRIMARY KEY(ID)


    , INDEX KSCO_COMMENT_I1 (TYPE)
    , INDEX KSCO_COMMENT_I2 (RT_DESCR_ID)
    , INDEX KSCO_COMMENT_I3 (REFERENCE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_COMMENT_ATTR
# -----------------------------------------------------------------------
drop table if exists KSCO_COMMENT_ATTR
/

CREATE TABLE KSCO_COMMENT_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_COMMENT_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSCO_COMMENT_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_COMMENT_TYPE
# -----------------------------------------------------------------------
drop table if exists KSCO_COMMENT_TYPE
/

CREATE TABLE KSCO_COMMENT_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_COMMENT_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_COMMENT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSCO_COMMENT_TYPE_ATTR
/

CREATE TABLE KSCO_COMMENT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_COMMENT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSCO_COMMENT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_REFERENCE
# -----------------------------------------------------------------------
drop table if exists KSCO_REFERENCE
/

CREATE TABLE KSCO_REFERENCE
(
      ID VARCHAR(255)
        , REFERENCE_ID VARCHAR(255)
        , REFERENCE_TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_REFERENCEP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0033779 UNIQUE (REFERENCE_ID, REFERENCE_TYPE)

    , INDEX KSCO_REFERENCE_I1 (REFERENCE_TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_REFERENCE_TYPE
# -----------------------------------------------------------------------
drop table if exists KSCO_REFERENCE_TYPE
/

CREATE TABLE KSCO_REFERENCE_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_REFERENCE_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_REFERENCE_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSCO_REFERENCE_TYPE_ATTR
/

CREATE TABLE KSCO_REFERENCE_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_REFERENCE_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSCO_REFERENCE_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSCO_RICH_TEXT_T
/

CREATE TABLE KSCO_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_TAG
# -----------------------------------------------------------------------
drop table if exists KSCO_TAG
/

CREATE TABLE KSCO_TAG
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME_SPACE VARCHAR(255)
        , PREDICATE VARCHAR(255)
        , STATE VARCHAR(255)
        , VAL VARCHAR(255)
        , REFERENCE VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSCO_TAGP1 PRIMARY KEY(ID)


    , INDEX KSCO_TAG_I1 (REFERENCE)
    , INDEX KSCO_TAG_I2 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_TAG_ATTR
# -----------------------------------------------------------------------
drop table if exists KSCO_TAG_ATTR
/

CREATE TABLE KSCO_TAG_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_TAG_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSCO_TAG_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_TAG_TYPE
# -----------------------------------------------------------------------
drop table if exists KSCO_TAG_TYPE
/

CREATE TABLE KSCO_TAG_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_TAG_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSCO_TAG_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSCO_TAG_TYPE_ATTR
/

CREATE TABLE KSCO_TAG_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSCO_TAG_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSCO_TAG_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT
/

CREATE TABLE KSDO_DOCUMENT
(
      DOC_ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , DOCUMENT LONGTEXT
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , FILE_NAME VARCHAR(255)
        , NAME VARCHAR(255)
        , STATE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSDO_DOCUMENTP1 PRIMARY KEY(DOC_ID)


    , INDEX KSDO_DOCUMENT_I1 (RT_DESCR_ID)
    , INDEX KSDO_DOCUMENT_I2 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_ATTR
/

CREATE TABLE KSDO_DOCUMENT_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_DOCUMENT_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_DOCUMENT_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_CATEGORY
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_CATEGORY
/

CREATE TABLE KSDO_DOCUMENT_CATEGORY
(
      CATEGORY_ID VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_DOCUMENT_CATEGORYP1 PRIMARY KEY(CATEGORY_ID)


    , INDEX KSDO_DOCUMENT_CATEGORY_I1 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_CATEGORY_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_CATEGORY_ATTR
/

CREATE TABLE KSDO_DOCUMENT_CATEGORY_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_DOCUMENT_CATEGORY_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_DOC_CATEGORY_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_JN_DOC_CATEGORY
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_JN_DOC_CATEGORY
/

CREATE TABLE KSDO_DOCUMENT_JN_DOC_CATEGORY
(
      DOC_ID VARCHAR(255) NOT NULL
        , CATEGORY_ID VARCHAR(255) NOT NULL
    


    , INDEX KSDO_DOC_JN_DOC_CATEGORY_I1 (DOC_ID)
    , INDEX KSDO_DOC_JN_DOC_CATEGORY_I2 (CATEGORY_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_TYPE
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_TYPE
/

CREATE TABLE KSDO_DOCUMENT_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_DOCUMENT_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_DOCUMENT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_DOCUMENT_TYPE_ATTR
/

CREATE TABLE KSDO_DOCUMENT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_DOCUMENT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_DOCUMENT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_DOC_RELTN
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_DOC_RELTN
/

CREATE TABLE KSDO_REF_DOC_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REF_OBJ_ID VARCHAR(255)
        , ST VARCHAR(255)
        , TITLE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , DOC_ID VARCHAR(255)
        , TYPE_KEY VARCHAR(255)
        , REF_OBJ_TYPE_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSDO_REF_DOC_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSDO_REF_DOC_RELTN_I1 (TYPE_KEY)
    , INDEX KSDO_REF_DOC_RELTN_I2 (REF_OBJ_TYPE_KEY)
    , INDEX KSDO_REF_DOC_RELTN_I3 (RT_DESCR_ID)
    , INDEX KSDO_REF_DOC_RELTN_I4 (DOC_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_DOC_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_DOC_RELTN_TYPE
/

CREATE TABLE KSDO_REF_DOC_RELTN_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_DOC_RELTN_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_DOC_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_DOC_RELTN_TYPE_ATTR
/

CREATE TABLE KSDO_REF_DOC_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_DOC_RELTN_TYPE_ATTP1 PRIMARY KEY(ID)


    , INDEX KSDO_REF_DOC_REL_TYP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_DOC_REL_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_DOC_REL_ATTR
/

CREATE TABLE KSDO_REF_DOC_REL_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_DOC_REL_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_REF_DOC_REL_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_OBJ_SUB_TYPE
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_OBJ_SUB_TYPE
/

CREATE TABLE KSDO_REF_OBJ_SUB_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , REF_OBJ_TYPE_KEY VARCHAR(255)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_OBJ_SUB_TYPEP1 PRIMARY KEY(TYPE_KEY)


    , INDEX KSDO_REF_OBJ_SUB_TYPE_I1 (REF_OBJ_TYPE_KEY)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_OBJ_SUB_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_OBJ_SUB_TYPE_ATTR
/

CREATE TABLE KSDO_REF_OBJ_SUB_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_OBJ_SUB_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_REF_OBJ_SUB_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_OBJ_TYPE
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_OBJ_TYPE
/

CREATE TABLE KSDO_REF_OBJ_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_OBJ_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_OBJ_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_OBJ_TYPE_ATTR
/

CREATE TABLE KSDO_REF_OBJ_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_REF_OBJ_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSDO_REF_OBJ_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_REF_REL_TYP_JN_SUB_TYP
# -----------------------------------------------------------------------
drop table if exists KSDO_REF_REL_TYP_JN_SUB_TYP
/

CREATE TABLE KSDO_REF_REL_TYP_JN_SUB_TYP
(
      REF_DOC_RELTN_TYPE_KEY VARCHAR(255) NOT NULL
        , REF_OBJ_SUB_TYPE_KEY VARCHAR(255) NOT NULL
    


    , INDEX KSDO_REF_REL_TYP_JN_SUBTYP_I1 (REF_OBJ_SUB_TYPE_KEY)
    , INDEX KSDO_REF_REL_TYP_JN_SUBTYP_I2 (REF_DOC_RELTN_TYPE_KEY)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSDO_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSDO_RICH_TEXT_T
/

CREATE TABLE KSDO_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSDO_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSEM_CTX_JN_ENUM_VAL_T
# -----------------------------------------------------------------------
drop table if exists KSEM_CTX_JN_ENUM_VAL_T
/

CREATE TABLE KSEM_CTX_JN_ENUM_VAL_T
(
      ENUM_VAL_ID VARCHAR(255) NOT NULL
        , CTX_ID VARCHAR(255) NOT NULL
    


    , INDEX KSEM_CTX_JN_ENUM_VAL_T_I1 (CTX_ID)
    , INDEX KSEM_CTX_JN_ENUM_VAL_T_I2 (ENUM_VAL_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSEM_CTX_T
# -----------------------------------------------------------------------
drop table if exists KSEM_CTX_T
/

CREATE TABLE KSEM_CTX_T
(
      ID VARCHAR(255)
        , CTX_KEY VARCHAR(255)
        , CTX_VAL VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSEM_CTX_TP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C00285110 UNIQUE (CTX_KEY, CTX_VAL)


) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSEM_ENUM_T
# -----------------------------------------------------------------------
drop table if exists KSEM_ENUM_T
/

CREATE TABLE KSEM_ENUM_T
(
      ENUM_KEY VARCHAR(255)
        , DESCR VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSEM_ENUM_TP1 PRIMARY KEY(ENUM_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSEM_ENUM_VAL_T
# -----------------------------------------------------------------------
drop table if exists KSEM_ENUM_VAL_T
/

CREATE TABLE KSEM_ENUM_VAL_T
(
      ID VARCHAR(255)
        , ABBREV_VAL VARCHAR(255)
        , CD VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , SORT_KEY DECIMAL(10)
        , VAL VARCHAR(255)
        , ENUM_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSEM_ENUM_VAL_TP1 PRIMARY KEY(ID)


    , INDEX KSEM_ENUM_VAL_I2 (CD)
    , INDEX KSEM_ENUM_VAL_T_I1 (ENUM_KEY)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_ATTR
/

CREATE TABLE KSLO_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO
# -----------------------------------------------------------------------
drop table if exists KSLO_LO
/

CREATE TABLE KSLO_LO
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , ST VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , LO_REPO_ID VARCHAR(255)
        , LOTYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLO_LOP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_I1 (RT_DESCR_ID)
    , INDEX KSLO_LO_I2 (LOTYPE_ID)
    , INDEX KSLO_LO_I3 (LO_REPO_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_ALLOWED_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_ALLOWED_RELTN_TYPE
/

CREATE TABLE KSLO_LO_ALLOWED_RELTN_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_TYPE_ID VARCHAR(255)
        , LO_REL_TYPE_ID VARCHAR(255)
        , LOLO_RELTN_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLO_LO_ALLOWED_RELTN_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_CATEGORY
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_CATEGORY
/

CREATE TABLE KSLO_LO_CATEGORY
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , STATE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , LO_CATEGORY_TYPE_ID VARCHAR(255)
        , LO_REPO_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLO_LO_CATEGORYP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_CATEGORY_I1 (RT_DESCR_ID)
    , INDEX KSLO_LO_CATEGORY_I2 (LO_REPO_ID)
    , INDEX KSLO_LO_CATEGORY_I3 (LO_CATEGORY_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_CATEGORY_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_CATEGORY_ATTR
/

CREATE TABLE KSLO_LO_CATEGORY_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_CATEGORY_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_CATEGORY_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_CATEGORY_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_CATEGORY_TYPE
/

CREATE TABLE KSLO_LO_CATEGORY_TYPE
(
      ID VARCHAR(255)
        , DESCR VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , TYPE_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
        , TYPE_DESC VARCHAR(2000)
    
    , CONSTRAINT KSLO_LO_CATEGORY_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_CATEGORY_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_CATEGORY_TYPE_ATTR
/

CREATE TABLE KSLO_LO_CATEGORY_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_CATEGORY_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_CATEGORY_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_JN_LOCATEGORY
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_JN_LOCATEGORY
/

CREATE TABLE KSLO_LO_JN_LOCATEGORY
(
      ID VARCHAR(255)
        , LO_ID VARCHAR(255)
        , LOCATEGORY_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_JN_LOCATEGORYP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011301 UNIQUE (LO_ID, LOCATEGORY_ID)

    , INDEX KSLO_LO_JN_LOCATEGORY_I1 (LOCATEGORY_ID)
    , INDEX KSLO_LO_JN_LOCATEGORY_I2 (LO_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_RELTN
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_RELTN
/

CREATE TABLE KSLO_LO_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , LO_ID VARCHAR(255)
        , LO_LO_RELATION_TYPE_ID VARCHAR(255)
        , RELATED_LO_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLO_LO_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_RELTN_I1 (LO_LO_RELATION_TYPE_ID)
    , INDEX KSLO_LO_RELTN_I2 (RELATED_LO_ID)
    , INDEX KSLO_LO_RELTN_I3 (LO_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_RELTN_ATTR
/

CREATE TABLE KSLO_LO_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_RELTN_TYPE
/

CREATE TABLE KSLO_LO_RELTN_TYPE
(
      ID VARCHAR(255)
        , DESCR VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , REV_DESCR VARCHAR(255)
        , REV_NAME VARCHAR(255)
        , TYPE_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
        , TYPE_DESC VARCHAR(2000)
    
    , CONSTRAINT KSLO_LO_RELTN_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_RELTN_TYPE_ATTR
/

CREATE TABLE KSLO_LO_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_RELTN_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_RELTN_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_REPOSITORY
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_REPOSITORY
/

CREATE TABLE KSLO_LO_REPOSITORY
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , LO_ROOT_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLO_LO_REPOSITORYP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_REPOSITORY_I1 (LO_ROOT_ID)
    , INDEX KSLO_LO_REPOSITORY_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_REPOSITORY_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_REPOSITORY_ATTR
/

CREATE TABLE KSLO_LO_REPOSITORY_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_REPOSITORY_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_REPOSITORY_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_TYPE
/

CREATE TABLE KSLO_LO_TYPE
(
      ID VARCHAR(255)
        , DESCR VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , TYPE_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
        , TYPE_DESC VARCHAR(2000)
    
    , CONSTRAINT KSLO_LO_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_LO_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLO_LO_TYPE_ATTR
/

CREATE TABLE KSLO_LO_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_LO_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLO_LO_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLO_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSLO_RICH_TEXT_T
/

CREATE TABLE KSLO_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLO_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESCOMP
# -----------------------------------------------------------------------
drop table if exists KSLR_RESCOMP
/

CREATE TABLE KSLR_RESCOMP
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , STATE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLR_RESCOMPP1 PRIMARY KEY(ID)


    , INDEX KSLR_RESCOMP_I1 (TYPE)
    , INDEX KSLR_RESCOMP_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESCOMP_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLR_RESCOMP_ATTR
/

CREATE TABLE KSLR_RESCOMP_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_RESCOMP_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLR_RESCOMP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESCOMP_JN_RESVALUE
# -----------------------------------------------------------------------
drop table if exists KSLR_RESCOMP_JN_RESVALUE
/

CREATE TABLE KSLR_RESCOMP_JN_RESVALUE
(
      COMPONENT_ID VARCHAR(255) NOT NULL
        , RESULT_ID VARCHAR(255) NOT NULL
    



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESCOMP_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLR_RESCOMP_TYPE
/

CREATE TABLE KSLR_RESCOMP_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_RESCOMP_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESCOMP_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLR_RESCOMP_TYPE_ATTR
/

CREATE TABLE KSLR_RESCOMP_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_RESCOMP_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLR_RESCOMP_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RESULT_VALUE
# -----------------------------------------------------------------------
drop table if exists KSLR_RESULT_VALUE
/

CREATE TABLE KSLR_RESULT_VALUE
(
      ID VARCHAR(255)
        , VALUE VARCHAR(255)
        , RSLT_COMP_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_RESULT_VALUEP1 PRIMARY KEY(ID)


    , INDEX KSLR_RESULT_VALUE_I1 (RSLT_COMP_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSLR_RICH_TEXT_T
/

CREATE TABLE KSLR_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_SCALE
# -----------------------------------------------------------------------
drop table if exists KSLR_SCALE
/

CREATE TABLE KSLR_SCALE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLR_SCALEP1 PRIMARY KEY(ID)


    , INDEX KSLR_SCALE_I1 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLR_SCALE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLR_SCALE_ATTR
/

CREATE TABLE KSLR_SCALE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLR_SCALE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLR_SCALE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU
/

CREATE TABLE KSLU_CLU
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , CURR_VER_END TIMESTAMP
        , CURR_VER_START TIMESTAMP
        , SEQ_NUM DECIMAL(19)
        , VER_CMT VARCHAR(255)
        , VER_IND_ID VARCHAR(255)
        , VER_FROM_ID VARCHAR(255)
        , CAN_CREATE_LUI DECIMAL(1)
        , DEF_ENRL_EST DECIMAL(10)
        , DEF_MAX_ENRL DECIMAL(10)
        , EFF_DT TIMESTAMP
        , EXP_FIRST_ATP VARCHAR(255)
        , EXPIR_DT TIMESTAMP
        , HAS_EARLY_DROP_DEDLN DECIMAL(1)
        , CLU_INTSTY_QTY VARCHAR(255)
        , CLU_INTSTY_TYPE VARCHAR(255)
        , IS_ENRL DECIMAL(1)
        , IS_HAZR_DISBLD_STU DECIMAL(1)
        , LAST_ADMIT_ATP VARCHAR(255)
        , LAST_ATP VARCHAR(255)
        , NEXT_REVIEW_PRD VARCHAR(255)
        , REF_URL VARCHAR(255)
        , ST VARCHAR(255)
        , ATP_DUR_TYP_KEY VARCHAR(255)
        , TM_QUANTITY DECIMAL(10)
        , STDY_SUBJ_AREA VARCHAR(255)
        , ACCT_ID VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , FEE_ID VARCHAR(255)
        , LUTYPE_ID VARCHAR(255)
        , OFFIC_CLU_ID VARCHAR(255)
        , PRI_INSTR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLUP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011370 UNIQUE (VER_IND_ID, SEQ_NUM)

    , INDEX KSLU_CLU_I1 (PRI_INSTR_ID)
    , INDEX KSLU_CLU_I2 (LUTYPE_ID)
    , INDEX KSLU_CLU_I3 (RT_DESCR_ID)
    , INDEX KSLU_CLU_I4 (FEE_ID)
    , INDEX KSLU_CLU_I5 (OFFIC_CLU_ID)
    , INDEX KSLU_CLU_I6 (ACCT_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLUCLU_RELTN
# -----------------------------------------------------------------------
drop table if exists KSLU_CLUCLU_RELTN
/

CREATE TABLE KSLU_CLUCLU_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , CLU_RELTN_REQ DECIMAL(1)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , LU_RELTN_TYPE_ID VARCHAR(255)
        , RELATED_CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLUCLU_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLUCLU_RELTN_I1 (CLU_ID)
    , INDEX KSLU_CLUCLU_RELTN_I2 (RELATED_CLU_ID)
    , INDEX KSLU_CLUCLU_RELTN_I3 (LU_RELTN_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLUCLU_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLUCLU_RELTN_ATTR
/

CREATE TABLE KSLU_CLUCLU_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLUCLU_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLUCLU_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLURES_JN_RESOPT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLURES_JN_RESOPT
/

CREATE TABLE KSLU_CLURES_JN_RESOPT
(
      CLU_RES_ID VARCHAR(255) NOT NULL
        , RES_OPT_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011378 UNIQUE (RES_OPT_ID)

    , INDEX KSLU_CLURES_JN_RESOPT_I1 (CLU_RES_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ACCRED
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ACCRED
/

CREATE TABLE KSLU_CLU_ACCRED
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ORG_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_ACCREDP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ACCRED_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ACCRED_ATTR
/

CREATE TABLE KSLU_CLU_ACCRED_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ACCRED_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ACCRED_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ACCT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ACCT
/

CREATE TABLE KSLU_CLU_ACCT
(
      ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ACCTP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ACCT_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ACCT_ATTR
/

CREATE TABLE KSLU_CLU_ACCT_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ACCT_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ACCT_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ACCT_JN_AFFIL_ORG
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ACCT_JN_AFFIL_ORG
/

CREATE TABLE KSLU_CLU_ACCT_JN_AFFIL_ORG
(
      CLU_ACCT_ID VARCHAR(255) NOT NULL
        , AFFIL_ORG_ID VARCHAR(255) NOT NULL
    


    , INDEX KSLU_CLU_ACCT_JN_AFFIL_ORG_I1 (AFFIL_ORG_ID)
    , INDEX KSLU_CLU_ACCT_JN_AFFIL_ORG_I2 (CLU_ACCT_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ADMIN_ORG
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ADMIN_ORG
/

CREATE TABLE KSLU_CLU_ADMIN_ORG
(
      ID VARCHAR(255)
        , IS_PR DECIMAL(1)
        , ORG_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ADMIN_ORGP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ADMIN_ORG_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ADMIN_ORG_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ADMIN_ORG_ATTR
/

CREATE TABLE KSLU_CLU_ADMIN_ORG_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ADMIN_ORG_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ADMIN_ORG_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_AFFIL_ORG
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_AFFIL_ORG
/

CREATE TABLE KSLU_CLU_AFFIL_ORG
(
      ID VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ORG_ID VARCHAR(255)
        , PERCT DECIMAL(19)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_AFFIL_ORGP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ATP_TYPE_KEY
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ATP_TYPE_KEY
/

CREATE TABLE KSLU_CLU_ATP_TYPE_KEY
(
      ID VARCHAR(255)
        , ATP_TYPE_KEY VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ATP_TYPE_KEYP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ATP_TYPE_KEY_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_ATTR
/

CREATE TABLE KSLU_CLU_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_CR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_CR
/

CREATE TABLE KSLU_CLU_CR
(
      ID VARCHAR(255)
        , INSTR_UNIT DECIMAL(10)
        , MAX_ALOW_INACV_ATP VARCHAR(255)
        , MAX_ALOW_INACV_TMQ DECIMAL(10)
        , MAX_TM_RSLT_RCGZ_ATP VARCHAR(255)
        , MAX_TM_RSLT_RCGZ_TMQ DECIMAL(10)
        , MAX_TM_TO_COMP_ATP VARCHAR(255)
        , MAX_TM_TO_COMP_TMQ DECIMAL(10)
        , MAX_TOT_UNIT DECIMAL(10)
        , MIN_TM_TO_COMP_ATP VARCHAR(255)
        , MIN_TM_TO_COMP_TMQ DECIMAL(10)
        , MIN_TOT_UNIT DECIMAL(10)
        , REPEAT_CNT VARCHAR(255)
        , REPEAT_TM_ATP VARCHAR(255)
        , REPEAT_TM_TMQ DECIMAL(10)
        , REPEAT_UNIT VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_CRP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE
/

CREATE TABLE KSLU_CLU_FEE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , RT_DESCR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_FEEP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_FEE_I1 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEEREC_JN_AFFIL_ORG
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEEREC_JN_AFFIL_ORG
/

CREATE TABLE KSLU_CLU_FEEREC_JN_AFFIL_ORG
(
      CLU_FEE_REC_ID VARCHAR(255) NOT NULL
        , AFFIL_ORG_ID VARCHAR(255) NOT NULL
    


    , INDEX KSLU_CLU_FEEREC_JN_AFF_ORG_I1 (AFFIL_ORG_ID)
    , INDEX KSLU_CLU_FEEREC_JN_AFF_ORG_I2 (CLU_FEE_REC_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE_AMOUNT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE_AMOUNT
/

CREATE TABLE KSLU_CLU_FEE_AMOUNT
(
      ID VARCHAR(255)
        , CURRENCY_QUANT DECIMAL(10)
        , CURRENCY_TYPE VARCHAR(255)
        , CLUE_FEE_REC_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_FEE_AMOUNTP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_FEE_AMOUNT_I1 (CLUE_FEE_REC_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE_ATTR
/

CREATE TABLE KSLU_CLU_FEE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_FEE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_FEE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE_JN_CLU_FEE_REC
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE_JN_CLU_FEE_REC
/

CREATE TABLE KSLU_CLU_FEE_JN_CLU_FEE_REC
(
      CLU_FEE_ID VARCHAR(255) NOT NULL
        , CLU_FEE_REC_ID VARCHAR(255) NOT NULL
    


    , INDEX KSLU_CLUFEE_JN_CLUFEE_REC_I1 (CLU_FEE_REC_ID)
    , INDEX KSLU_CLUFEE_JN_CLUFEE_REC_I2 (CLU_FEE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE_REC
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE_REC
/

CREATE TABLE KSLU_CLU_FEE_REC
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , FEE_TYPE VARCHAR(255)
        , RATE_TYPE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_FEE_RECP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_FEE_REC_I1 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_FEE_REC_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_FEE_REC_ATTR
/

CREATE TABLE KSLU_CLU_FEE_REC_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_FEE_REC_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_FEE_REC_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_IDENT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_IDENT
/

CREATE TABLE KSLU_CLU_IDENT
(
      ID VARCHAR(255)
        , CD VARCHAR(255)
        , DIV VARCHAR(255)
        , LVL VARCHAR(255)
        , LNG_NAME VARCHAR(255)
        , ORG_ID VARCHAR(255)
        , SHRT_NAME VARCHAR(255)
        , ST VARCHAR(255)
        , SUFX_CD VARCHAR(255)
        , TYPE VARCHAR(255)
        , VARTN VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_IDENTP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_IDENT_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_IDENT_ATTR
/

CREATE TABLE KSLU_CLU_IDENT_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_INSTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_INSTR
/

CREATE TABLE KSLU_CLU_INSTR
(
      ID VARCHAR(255)
        , ORG_ID VARCHAR(255)
        , PERS_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_INSTRP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_INSTR_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_INSTR_ATTR
/

CREATE TABLE KSLU_CLU_INSTR_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_INSTR_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_INSTR_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_JN_ACCRED
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_JN_ACCRED
/

CREATE TABLE KSLU_CLU_JN_ACCRED
(
      CLU_ID VARCHAR(255) NOT NULL
        , CLU_ACCRED_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011436 UNIQUE (CLU_ACCRED_ID)

    , INDEX KSLU_CLU_JN_ACCRED_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_JN_CAMP_LOC
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_JN_CAMP_LOC
/

CREATE TABLE KSLU_CLU_JN_CAMP_LOC
(
      ID VARCHAR(255)
        , CAMP_LOC VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_JN_CAMP_LOCP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_JN_CAMP_LOC_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_JN_CLU_IDENT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_JN_CLU_IDENT
/

CREATE TABLE KSLU_CLU_JN_CLU_IDENT
(
      CLU_ID VARCHAR(255) NOT NULL
        , ALT_CLU_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011441 UNIQUE (ALT_CLU_ID)

    , INDEX KSLU_CLU_JN_CLU_IDENT_I2 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_JN_CLU_INSTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_JN_CLU_INSTR
/

CREATE TABLE KSLU_CLU_JN_CLU_INSTR
(
      CLU_ID VARCHAR(255) NOT NULL
        , CLU_INSTR_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011444 UNIQUE (CLU_INSTR_ID)

    , INDEX KSLU_CLU_JN_CLU_INSTR_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_JN_SUBJ_ORG
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_JN_SUBJ_ORG
/

CREATE TABLE KSLU_CLU_JN_SUBJ_ORG
(
      ID VARCHAR(255)
        , ORG_ID VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_JN_SUBJ_ORGP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_JN_SUBJ_ORG_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_LO_ALOW_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_LO_ALOW_RELTN_TYPE
/

CREATE TABLE KSLU_CLU_LO_ALOW_RELTN_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_TYPE_ID VARCHAR(255)
        , CLULO_RELTN_TYPE_ID VARCHAR(255)
        , LU_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_LO_ALOW_RELTN_TYPEP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_LO_ALOW_REL_TYPE_I1 (LU_TYPE_ID)
    , INDEX KSLU_CLU_LO_ALOW_REL_TYPE_I2 (CLULO_RELTN_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_LO_RELTN
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_LO_RELTN
/

CREATE TABLE KSLU_CLU_LO_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_ID VARCHAR(255)
        , ST VARCHAR(255)
        , TYPE VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_LO_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_LO_RELTN_I1 (CLU_ID)
    , INDEX KSLU_CLU_LO_RELTN_I2 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_LO_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_LO_RELTN_ATTR
/

CREATE TABLE KSLU_CLU_LO_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_LO_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_LO_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_LO_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_LO_RELTN_TYPE
/

CREATE TABLE KSLU_CLU_LO_RELTN_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_LO_RELTN_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_LO_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_LO_RELTN_TYPE_ATTR
/

CREATE TABLE KSLU_CLU_LO_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_LO_RELTN_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_LO_REL_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL
/

CREATE TABLE KSLU_CLU_PUBL
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , END_CYCLE VARCHAR(255)
        , EXPIR_DT TIMESTAMP
        , START_CYCLE VARCHAR(255)
        , ST VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , CLU_PUB_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_PUBLP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_PUBL_I1 (CLU_ID)
    , INDEX KSLU_CLU_PUBL_I2 (CLU_PUB_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL_ATTR
/

CREATE TABLE KSLU_CLU_PUBL_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_PUBL_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_PUBL_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL_JN_CLU_INSTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL_JN_CLU_INSTR
/

CREATE TABLE KSLU_CLU_PUBL_JN_CLU_INSTR
(
      CLU_PUBL_ID VARCHAR(255) NOT NULL
        , CLU_INSTR_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C009456 UNIQUE (CLU_INSTR_ID)


) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL_TYPE
/

CREATE TABLE KSLU_CLU_PUBL_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_PUBL_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL_TYPE_ATTR
/

CREATE TABLE KSLU_CLU_PUBL_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_PUBL_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_PUBL_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUBL_VARI
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUBL_VARI
/

CREATE TABLE KSLU_CLU_PUBL_VARI
(
      ID VARCHAR(255)
        , VARI_KEY VARCHAR(255)
        , VARI_VALUE VARCHAR(2500)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_PUBL_VARIP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011470 UNIQUE (VARI_KEY, OWNER)

    , INDEX KSLU_CLU_PUBL_VARI_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUB_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUB_TYPE
/

CREATE TABLE KSLU_CLU_PUB_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_PUB_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_PUB_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_PUB_TYPE_ATTR
/

CREATE TABLE KSLU_CLU_PUB_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_PUB_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_PUB_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_RESULT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_RESULT_TYPE_ATTR
/

CREATE TABLE KSLU_CLU_RESULT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_RESULT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_RESULT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_RSLT
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_RSLT
/

CREATE TABLE KSLU_CLU_RSLT
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , TYPE_KEY_ID VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_RSLTP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_RSLT_I1 (TYPE_KEY_ID)
    , INDEX KSLU_CLU_RSLT_I2 (CLU_ID)
    , INDEX KSLU_CLU_RSLT_I3 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_RSLT_LU_ALOW_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_RSLT_LU_ALOW_TYPE
/

CREATE TABLE KSLU_CLU_RSLT_LU_ALOW_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , CLU_RSLT_TYPE_ID VARCHAR(255)
        , LU_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_RSLT_LU_ALOW_TYPEP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_RSLT_LU_ALOW_TYPE_I1 (CLU_RSLT_TYPE_ID)
    , INDEX KSLU_CLU_RSLT_LU_ALOW_TYPE_I2 (LU_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_RSLT_TYP
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_RSLT_TYP
/

CREATE TABLE KSLU_CLU_RSLT_TYP
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_RSLT_TYPP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET
/

CREATE TABLE KSLU_CLU_SET
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , ADMIN_ORG_ID VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REFERENCEABLE DECIMAL(1)
        , REUSABLE DECIMAL(1)
        , NAME VARCHAR(255)
        , ST VARCHAR(255)
        , TYPE VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , MEM_QUERY_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_SETP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_SET_I1 (MEM_QUERY_ID)
    , INDEX KSLU_CLU_SET_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET_ATTR
/

CREATE TABLE KSLU_CLU_SET_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_SET_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_SET_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET_JN_CLU
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET_JN_CLU
/

CREATE TABLE KSLU_CLU_SET_JN_CLU
(
      CLU_SET_ID VARCHAR(255) NOT NULL
        , CLU_VER_IND_ID VARCHAR(255) NOT NULL
        , ID VARCHAR(255)
        , VER_NBR DECIMAL(19)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_CLU_SET_JN_CLUP1 PRIMARY KEY(ID)

    , CONSTRAINT KSLU_CLU_SET_JN_CLU_I1 UNIQUE (CLU_SET_ID, CLU_VER_IND_ID)


) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET_JN_CLU_SET
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET_JN_CLU_SET
/

CREATE TABLE KSLU_CLU_SET_JN_CLU_SET
(
      CLU_SET_PARENT_ID VARCHAR(255) NOT NULL
        , CLU_SET_CHILD_ID VARCHAR(255) NOT NULL
    


    , INDEX KSLU_CLU_SET_JN_CLU_SET_I1 (CLU_SET_PARENT_ID)
    , INDEX KSLU_CLU_SET_JN_CLU_SET_I2 (CLU_SET_CHILD_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET_TYPE
/

CREATE TABLE KSLU_CLU_SET_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_SET_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_CLU_SET_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_CLU_SET_TYPE_ATTR
/

CREATE TABLE KSLU_CLU_SET_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_CLU_SET_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_CLU_SET_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_DLVMTHD_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_DLVMTHD_TYPE
/

CREATE TABLE KSLU_DLVMTHD_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_DLVMTHD_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_DLVMTHD_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_DLVMTHD_TYPE_ATTR
/

CREATE TABLE KSLU_DLVMTHD_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_DLVMTHD_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_DLVMTHD_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_INSTFRMT_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_INSTFRMT_TYPE
/

CREATE TABLE KSLU_INSTFRMT_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_INSTFRMT_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_INSTFRMT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_INSTFRMT_TYPE_ATTR
/

CREATE TABLE KSLU_INSTFRMT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_INSTFRMT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_INSTFRMT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LUI
# -----------------------------------------------------------------------
drop table if exists KSLU_LUI
/

CREATE TABLE KSLU_LUI
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , ATP_ID VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXP_DT TIMESTAMP
        , LUI_CODE VARCHAR(255)
        , MAX_SEATS DECIMAL(10)
        , ST VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_LUIP1 PRIMARY KEY(ID)


    , INDEX KSLU_LUI_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LUILUI_RELTN
# -----------------------------------------------------------------------
drop table if exists KSLU_LUILUI_RELTN
/

CREATE TABLE KSLU_LUILUI_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , LULU_RELTN_TYPE_ID VARCHAR(255)
        , LUI_ID VARCHAR(255)
        , RELATED_LUI_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_LUILUI_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSLU_LUILUI_RELTN_I1 (RELATED_LUI_ID)
    , INDEX KSLU_LUILUI_RELTN_I2 (LULU_RELTN_TYPE_ID)
    , INDEX KSLU_LUILUI_RELTN_I3 (LUI_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LUILUI_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LUILUI_RELTN_ATTR
/

CREATE TABLE KSLU_LUILUI_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LUILUI_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LUILUI_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LUI_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LUI_ATTR
/

CREATE TABLE KSLU_LUI_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LUI_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LUI_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LULU_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_LULU_RELTN_TYPE
/

CREATE TABLE KSLU_LULU_RELTN_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , DESCR VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , REV_DESC VARCHAR(255)
        , REV_NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_LULU_RELTN_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LULU_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LULU_RELTN_TYPE_ATTR
/

CREATE TABLE KSLU_LULU_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LULU_RELTN_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LULU_RELTN_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LULU_RELTN_TYPE_JN_LU_TYP
# -----------------------------------------------------------------------
drop table if exists KSLU_LULU_RELTN_TYPE_JN_LU_TYP
/

CREATE TABLE KSLU_LULU_RELTN_TYPE_JN_LU_TYP
(
      LULU_RELTN_TYPE_ID VARCHAR(255) NOT NULL
        , LU_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSLU_LULU_RELTYP_JN_LUTYP_I1 (LULU_RELTN_TYPE_ID)
    , INDEX KSLU_LULU_RELTYP_JN_LUTYP_I2 (LU_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LUTYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_LUTYPE
/

CREATE TABLE KSLU_LUTYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , DLVR_MTHD VARCHAR(255)
        , INSTR_FRMT VARCHAR(255)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LUTYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_CD_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_CD_TYPE
/

CREATE TABLE KSLU_LU_CD_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_CD_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_CD_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_CD_TYPE_ATTR
/

CREATE TABLE KSLU_LU_CD_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_CD_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_CD_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_CODE
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_CODE
/

CREATE TABLE KSLU_LU_CODE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , DESCR VARCHAR(255)
        , TYPE VARCHAR(255)
        , VALUE VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_LU_CODEP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_CODE_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_CODE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_CODE_ATTR
/

CREATE TABLE KSLU_LU_CODE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_CODE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_CODE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_LU_ALOW_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_LU_ALOW_RELTN_TYPE
/

CREATE TABLE KSLU_LU_LU_ALOW_RELTN_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LU_TYPE_ID VARCHAR(255)
        , LU_REL_TYPE_ID VARCHAR(255)
        , LU_LU_RELTN_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_LU_LU_ALOW_RELTN_TYPEP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I1 (LU_REL_TYPE_ID)
    , INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I2 (LU_LU_RELTN_TYPE_ID)
    , INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I3 (LU_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_PUBL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_PUBL_TYPE
/

CREATE TABLE KSLU_LU_PUBL_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_PUBL_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_PUBL_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_PUBL_TYPE_ATTR
/

CREATE TABLE KSLU_LU_PUBL_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_PUBL_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_PUBL_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_LU_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_LU_TYPE_ATTR
/

CREATE TABLE KSLU_LU_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_LU_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_LU_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_MEMSHIP
# -----------------------------------------------------------------------
drop table if exists KSLU_MEMSHIP
/

CREATE TABLE KSLU_MEMSHIP
(
      ID VARCHAR(255)
        , SEARCH_TYPE_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_MEMSHIPP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_MEMSHIP_KSLU_SPARAM
# -----------------------------------------------------------------------
drop table if exists KSLU_MEMSHIP_KSLU_SPARAM
/

CREATE TABLE KSLU_MEMSHIP_KSLU_SPARAM
(
      KSLU_MEMSHIP_ID VARCHAR(255) NOT NULL
        , SEARCHPARAMETERS_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011543 UNIQUE (SEARCHPARAMETERS_ID)

    , INDEX KSLU_MEMSHIP_KSLU_SPARAM_I1 (KSLU_MEMSHIP_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSLU_RICH_TEXT_T
/

CREATE TABLE KSLU_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(4000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSLTUSAGE_LU_ALOW_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_RSLTUSAGE_LU_ALOW_TYPE
/

CREATE TABLE KSLU_RSLTUSAGE_LU_ALOW_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LU_TYPE_ID VARCHAR(255)
        , CLU_RSLT_USAGE_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_RSLTUSAGE_LU_ALOW_TYPEP1 PRIMARY KEY(ID)


    , INDEX KSLU_RSLTUSAGE_LU_ALOW_TYP_I1 (CLU_RSLT_USAGE_TYPE_ID)
    , INDEX KSLU_RSLTUSAGE_LU_ALOW_TYP_I2 (LU_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSLT_COMP_USG_ALOW_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_RSLT_COMP_USG_ALOW_TYPE
/

CREATE TABLE KSLU_RSLT_COMP_USG_ALOW_TYPE
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , RSLT_COMP_ID VARCHAR(255)
        , RSLT_USG_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_RSLT_COMP_USG_ALOW_TYPP1 PRIMARY KEY(ID)


    , INDEX KSLU_RSLTCOMP_USG_ALOW_TYP_I1 (RSLT_USG_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSLT_OPT
# -----------------------------------------------------------------------
drop table if exists KSLU_RSLT_OPT
/

CREATE TABLE KSLU_RSLT_OPT
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , RES_COMP_ID VARCHAR(255)
        , ST VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , RES_USAGE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSLU_RSLT_OPTP1 PRIMARY KEY(ID)


    , INDEX KSLU_RSLT_OPT_I1 (RES_USAGE_ID)
    , INDEX KSLU_RSLT_OPT_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSLT_USG_TYPE
# -----------------------------------------------------------------------
drop table if exists KSLU_RSLT_USG_TYPE
/

CREATE TABLE KSLU_RSLT_USG_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_RSLT_USG_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSLT_USG_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSLU_RSLT_USG_TYPE_ATTR
/

CREATE TABLE KSLU_RSLT_USG_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_RSLT_USG_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSLU_RSLT_USG_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_RSRC
# -----------------------------------------------------------------------
drop table if exists KSLU_RSRC
/

CREATE TABLE KSLU_RSRC
(
      ID VARCHAR(255)
        , RSRC_TYPE_ID VARCHAR(255)
        , CLU_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_RSRCP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011561 UNIQUE (RSRC_TYPE_ID, CLU_ID)

    , INDEX KSLU_RSRC_I1 (CLU_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_SPARAM
# -----------------------------------------------------------------------
drop table if exists KSLU_SPARAM
/

CREATE TABLE KSLU_SPARAM
(
      ID VARCHAR(255)
        , SEARCH_PARAM_KEY VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_SPARAMP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_SPARAM_KSLU_SPVALUE
# -----------------------------------------------------------------------
drop table if exists KSLU_SPARAM_KSLU_SPVALUE
/

CREATE TABLE KSLU_SPARAM_KSLU_SPVALUE
(
      KSLU_SPARAM_ID VARCHAR(255) NOT NULL
        , VALUES_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011566 UNIQUE (VALUES_ID)

    , INDEX KSLU_SPARAM_KSLU_SPVALUE_I1 (KSLU_SPARAM_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSLU_SPVALUE
# -----------------------------------------------------------------------
drop table if exists KSLU_SPVALUE
/

CREATE TABLE KSLU_SPVALUE
(
      ID VARCHAR(255)
        , VALUE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSLU_SPVALUEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSMG_MESSAGE
# -----------------------------------------------------------------------
drop table if exists KSMG_MESSAGE
/

CREATE TABLE KSMG_MESSAGE
(
      ID VARCHAR(255)
        , MSG_ID VARCHAR(255)
        , LOCALE VARCHAR(255)
        , GRP_NAME VARCHAR(255)
        , MSG_VALUE VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSMG_MESSAGEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG
/

CREATE TABLE KSOR_ORG
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LNG_DESCR VARCHAR(2000)
        , LNG_NAME VARCHAR(255)
        , SHRT_DESCR VARCHAR(500)
        , SHRT_NAME VARCHAR(255)
        , ST VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSOR_ORGP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_I1 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_ATTR
/

CREATE TABLE KSOR_ORG_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_HIRCHY
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_HIRCHY
/

CREATE TABLE KSOR_ORG_HIRCHY
(
      ID VARCHAR(255)
        , DESCR VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , ROOT_ORG VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_HIRCHYP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_HIRCHY_I1 (ROOT_ORG)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_HIRCHY_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_HIRCHY_ATTR
/

CREATE TABLE KSOR_ORG_HIRCHY_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_HIRCHY_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_HIRCHY_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_HIRCHY_JN_ORG_TYPE
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_HIRCHY_JN_ORG_TYPE
/

CREATE TABLE KSOR_ORG_HIRCHY_JN_ORG_TYPE
(
      ORG_HIRCHY_ID VARCHAR(255) NOT NULL
        , ORG_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSOR_ORG_HIRCHY_JN_ORG_TYP_I1 (ORG_HIRCHY_ID)
    , INDEX KSOR_ORG_HIRCHY_JN_ORG_TYP_I2 (ORG_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_JN_ORG_PERS_REL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_JN_ORG_PERS_REL_TYPE
/

CREATE TABLE KSOR_ORG_JN_ORG_PERS_REL_TYPE
(
      ORG_ID VARCHAR(255) NOT NULL
        , ORG_PERS_RELTN_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSOR_ORG_JN_ORG_PERREL_TYP_I1 (ORG_PERS_RELTN_TYPE_ID)
    , INDEX KSOR_ORG_JN_ORG_PERREL_TYP_I2 (ORG_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_ORG_RELTN
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_ORG_RELTN
/

CREATE TABLE KSOR_ORG_ORG_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , ORG VARCHAR(255)
        , RELATED_ORG VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSOR_ORG_ORG_RELTNP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_ORG_RELTN_I1 (ORG)
    , INDEX KSOR_ORG_ORG_RELTN_I2 (RELATED_ORG)
    , INDEX KSOR_ORG_ORG_RELTN_I3 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_ORG_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_ORG_RELTN_ATTR
/

CREATE TABLE KSOR_ORG_ORG_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_ORG_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_ORG_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_ORG_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_ORG_RELTN_TYPE
/

CREATE TABLE KSOR_ORG_ORG_RELTN_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , REV_DESCR VARCHAR(255)
        , REV_NAME VARCHAR(255)
        , ORG_HIRCHY VARCHAR(255)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_ORG_RELTN_TYPEP1 PRIMARY KEY(TYPE_KEY)


    , INDEX KSOR_ORG_ORG_RELTN_TYPE_I1 (ORG_HIRCHY)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_ORG_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_ORG_RELTN_TYPE_ATTR
/

CREATE TABLE KSOR_ORG_ORG_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_ORG_RELTN_TYPE_ATTP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_ORG_REL_TYP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_PERS_RELTN
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_PERS_RELTN
/

CREATE TABLE KSOR_ORG_PERS_RELTN
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , PERS_ID VARCHAR(255)
        , ST VARCHAR(255)
        , ORG VARCHAR(255)
        , ORG_PERS_RELTN_TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSOR_ORG_PERS_RELTNP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011691 UNIQUE (ORG_PERS_RELTN_TYPE, ORG, PERS_ID)

    , INDEX KSOR_ORG_PERS_RELTN_I1 (ORG)
    , INDEX KSOR_ORG_PERS_RELTN_I2 (ORG_PERS_RELTN_TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_PERS_RELTN_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_PERS_RELTN_ATTR
/

CREATE TABLE KSOR_ORG_PERS_RELTN_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_PERS_RELTN_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_PERS_RELTN_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_PERS_RELTN_TYPE
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_PERS_RELTN_TYPE
/

CREATE TABLE KSOR_ORG_PERS_RELTN_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_PERS_RELTN_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_PERS_RELTN_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_PERS_RELTN_TYPE_ATTR
/

CREATE TABLE KSOR_ORG_PERS_RELTN_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_PERS_RELTN_TYPE_ATP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_PERS_REL_TYP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_POS_RESTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_POS_RESTR
/

CREATE TABLE KSOR_ORG_POS_RESTR
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , DESCR VARCHAR(2000)
        , MAX_NUM_RELTN VARCHAR(255)
        , MIN_NUM_RELTN DECIMAL(10)
        , ATP_DUR_TYP_KEY VARCHAR(255)
        , TM_QUANTITY DECIMAL(10)
        , TTL VARCHAR(255)
        , ORG VARCHAR(255)
        , PERS_RELTN_TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSOR_ORG_POS_RESTRP1 PRIMARY KEY(ID)

    , CONSTRAINT SYS_C0011701 UNIQUE (ORG, PERS_RELTN_TYPE)

    , INDEX KSOR_ORG_POS_RESTR_I1 (PERS_RELTN_TYPE)
    , INDEX KSOR_ORG_POS_RESTR_I2 (ORG)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_POS_RESTR_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_POS_RESTR_ATTR
/

CREATE TABLE KSOR_ORG_POS_RESTR_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_POS_RESTR_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_POS_RESTR_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_TYPE
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_TYPE
/

CREATE TABLE KSOR_ORG_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_TYPE_ATTR
/

CREATE TABLE KSOR_ORG_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSOR_ORG_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSOR_ORG_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSOR_ORG_TYPE_JN_ORG_PERRL_TYP
# -----------------------------------------------------------------------
drop table if exists KSOR_ORG_TYPE_JN_ORG_PERRL_TYP
/

CREATE TABLE KSOR_ORG_TYPE_JN_ORG_PERRL_TYP
(
      ORG_TYPE_ID VARCHAR(255) NOT NULL
        , ORG_PERS_RELTN_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSOR_ORGTYP_JN_ORGPREL_TYP_I1 (ORG_PERS_RELTN_TYPE_ID)
    , INDEX KSOR_ORGTYP_JN_ORGPREL_TYP_I2 (ORG_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL
/

CREATE TABLE KSPR_PROPOSAL
(
      PROPOSAL_ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , DETAIL_DESC VARCHAR(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , RATIONALE VARCHAR(255)
        , STATE VARCHAR(255)
        , WORKFLOW_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSPR_PROPOSALP1 PRIMARY KEY(PROPOSAL_ID)


    , INDEX KSPR_PROPOSAL_I1 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_ATTR
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_ATTR
/

CREATE TABLE KSPR_PROPOSAL_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSPR_PROPOSAL_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_JN_ORG
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_JN_ORG
/

CREATE TABLE KSPR_PROPOSAL_JN_ORG
(
      ORGREF_ID VARCHAR(255)
        , ORG_ID VARCHAR(255)
        , PROPOSAL_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_JN_ORGP1 PRIMARY KEY(ORGREF_ID)


    , INDEX KSPR_PROPOSAL_JN_ORG_I1 (PROPOSAL_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_JN_PERSON
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_JN_PERSON
/

CREATE TABLE KSPR_PROPOSAL_JN_PERSON
(
      ID VARCHAR(255)
        , PERSONREF_ID VARCHAR(255)
        , PROPOSAL_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_JN_PERSONP1 PRIMARY KEY(ID)


    , INDEX KSPR_PROPOSAL_JN_PERSON_I1 (PROPOSAL_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_JN_REFERENCE
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_JN_REFERENCE
/

CREATE TABLE KSPR_PROPOSAL_JN_REFERENCE
(
      PROPOSAL_ID VARCHAR(255) NOT NULL
        , REFERENCE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSPR_PROPOSAL_JN_REFERENCE_I1 (REFERENCE_ID)
    , INDEX KSPR_PROPOSAL_JN_REFERENCE_I2 (PROPOSAL_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_REFERENCE
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_REFERENCE
/

CREATE TABLE KSPR_PROPOSAL_REFERENCE
(
      REFERENCE_ID VARCHAR(255)
        , OBJECT_REFERENCE_ID VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_REFERENCEP1 PRIMARY KEY(REFERENCE_ID)


    , INDEX KSPR_PROPOSAL_REFERENCE_I1 (TYPE)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_REFTYPE
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_REFTYPE
/

CREATE TABLE KSPR_PROPOSAL_REFTYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_REFTYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_REFTYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_REFTYPE_ATTR
/

CREATE TABLE KSPR_PROPOSAL_REFTYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_REFTYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSPR_PROPOSAL_REFTYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_TYPE
/

CREATE TABLE KSPR_PROPOSAL_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_PROPOSAL_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSPR_PROPOSAL_TYPE_ATTR
/

CREATE TABLE KSPR_PROPOSAL_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_PROPOSAL_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSPR_PROPOSAL_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSPR_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSPR_RICH_TEXT_T
/

CREATE TABLE KSPR_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSPR_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSSC_SUBJ_CD
# -----------------------------------------------------------------------
drop table if exists KSSC_SUBJ_CD
/

CREATE TABLE KSSC_SUBJ_CD
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , NAME VARCHAR(255)
        , STATE VARCHAR(255)
        , CD VARCHAR(255)
        , TYPE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSSC_SUBJ_CDP1 PRIMARY KEY(ID)

    , CONSTRAINT KSSC_SUBJ_CD_IX1 UNIQUE (CD)


) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSSC_SUBJ_CD_JN_ORG
# -----------------------------------------------------------------------
drop table if exists KSSC_SUBJ_CD_JN_ORG
/

CREATE TABLE KSSC_SUBJ_CD_JN_ORG
(
      ID VARCHAR(255)
        , ORG_ID VARCHAR(255)
        , SUBJ_CD_ID VARCHAR(255)
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSSC_SUBJ_CD_JN_ORGP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSSC_SUBJ_CD_TYPE
# -----------------------------------------------------------------------
drop table if exists KSSC_SUBJ_CD_TYPE
/

CREATE TABLE KSSC_SUBJ_CD_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSSC_SUBJ_CD_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_NL_USAGE_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_NL_USAGE_TYPE
/

CREATE TABLE KSST_NL_USAGE_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_NL_USAGE_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_OBJECT_SUB_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_OBJECT_SUB_TYPE
/

CREATE TABLE KSST_OBJECT_SUB_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_OBJECT_SUB_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_OBJECT_SUB_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_OBJECT_SUB_TYPE_ATTR
/

CREATE TABLE KSST_OBJECT_SUB_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_OBJECT_SUB_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_OBJECT_SUB_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_OBJECT_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_OBJECT_TYPE
/

CREATE TABLE KSST_OBJECT_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_OBJECT_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_OBJECT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_OBJECT_TYPE_ATTR
/

CREATE TABLE KSST_OBJECT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_OBJECT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_OBJECT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_OBJ_TYP_JN_OBJ_SUB_TYP
# -----------------------------------------------------------------------
drop table if exists KSST_OBJ_TYP_JN_OBJ_SUB_TYP
/

CREATE TABLE KSST_OBJ_TYP_JN_OBJ_SUB_TYP
(
      OBJ_TYPE_ID VARCHAR(255) NOT NULL
        , OBJ_SUB_TYPE_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011792 UNIQUE (OBJ_SUB_TYPE_ID)

    , INDEX KSST_OBJ_TYP_JN_OBJ_SUBTYP_I2 (OBJ_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_RCTYP_JN_RCFLDTYP
# -----------------------------------------------------------------------
drop table if exists KSST_RCTYP_JN_RCFLDTYP
/

CREATE TABLE KSST_RCTYP_JN_RCFLDTYP
(
      REQ_COMP_TYPE_ID VARCHAR(255) NOT NULL
        , REQ_COMP_FIELD_TYPE_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT IX1 UNIQUE (REQ_COMP_TYPE_ID, REQ_COMP_FIELD_TYPE_ID)

    , INDEX KSST_RCTYP_JN_RCFLDTYP_I1 (REQ_COMP_FIELD_TYPE_ID)
    , INDEX KSST_RCTYP_JN_RCFLDTYP_I2 (REQ_COMP_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_RC_JN_RC_FIELD
# -----------------------------------------------------------------------
drop table if exists KSST_RC_JN_RC_FIELD
/

CREATE TABLE KSST_RC_JN_RC_FIELD
(
      REQ_COM_ID VARCHAR(255) NOT NULL
        , REQ_COM_FIELD_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011797 UNIQUE (REQ_COM_FIELD_ID)

    , INDEX KSST_RC_JN_RC_FIELD_I1 (REQ_COM_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REF_STMT_REL
# -----------------------------------------------------------------------
drop table if exists KSST_REF_STMT_REL
/

CREATE TABLE KSST_REF_STMT_REL
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REF_OBJ_ID VARCHAR(255)
        , REF_OBJ_TYPE_KEY VARCHAR(255)
        , ST VARCHAR(255)
        , REF_STMT_REL_TYPE_ID VARCHAR(255)
        , STMT_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSST_REF_STMT_RELP1 PRIMARY KEY(ID)


    , INDEX KSST_REF_STMT_REL_I1 (REF_STMT_REL_TYPE_ID)
    , INDEX KSST_REF_STMT_REL_I2 (STMT_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REF_STMT_REL_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_REF_STMT_REL_ATTR
/

CREATE TABLE KSST_REF_STMT_REL_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REF_STMT_REL_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_REF_STMT_REL_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REF_STMT_REL_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_REF_STMT_REL_TYPE
/

CREATE TABLE KSST_REF_STMT_REL_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REF_STMT_REL_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REF_STMT_REL_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_REF_STMT_REL_TYPE_ATTR
/

CREATE TABLE KSST_REF_STMT_REL_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REF_STMT_REL_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_REF_STMT_REL_TYP_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM
/

CREATE TABLE KSST_REQ_COM
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , REQ_COM_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSST_REQ_COMP1 PRIMARY KEY(ID)


    , INDEX KSST_REQ_COM_I1 (REQ_COM_TYPE_ID)
    , INDEX KSST_REQ_COM_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM_FIELD
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM_FIELD
/

CREATE TABLE KSST_REQ_COM_FIELD
(
      ID VARCHAR(255)
        , REQ_COM_FIELD_TYPE VARCHAR(255)
        , VALUE VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REQ_COM_FIELDP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM_FIELD_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM_FIELD_TYPE
/

CREATE TABLE KSST_REQ_COM_FIELD_TYPE
(
      ID VARCHAR(255)
        , DATA_TYPE VARCHAR(255) NOT NULL
        , DESCR VARCHAR(255) NOT NULL
        , INVALID_CHARS VARCHAR(255)
        , MAX_LENGTH DECIMAL(10)
        , MAX_OCCURS DECIMAL(10)
        , MAX_VALUE VARCHAR(255)
        , MIN_LENGTH DECIMAL(10)
        , MIN_OCCURS DECIMAL(10)
        , MIN_VALUE VARCHAR(255)
        , NAME VARCHAR(255) NOT NULL
        , READ_ONLY DECIMAL(1) NOT NULL
        , VALID_CHARS VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REQ_COM_FIELD_TYPEP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM_TYPE
/

CREATE TABLE KSST_REQ_COM_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REQ_COM_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM_TYPE_ATTR
/

CREATE TABLE KSST_REQ_COM_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REQ_COM_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_REQ_COM_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_REQ_COM_TYPE_NL_TMPL
# -----------------------------------------------------------------------
drop table if exists KSST_REQ_COM_TYPE_NL_TMPL
/

CREATE TABLE KSST_REQ_COM_TYPE_NL_TMPL
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , LANGUAGE VARCHAR(2)
        , NL_USUAGE_TYPE_KEY VARCHAR(255)
        , TEMPLATE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_REQ_COM_TYPE_NL_TMPLP1 PRIMARY KEY(ID)


    , INDEX KSST_REQ_COM_TYPE_NL_TMPL_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_RICH_TEXT_T
# -----------------------------------------------------------------------
drop table if exists KSST_RICH_TEXT_T
/

CREATE TABLE KSST_RICH_TEXT_T
(
      ID VARCHAR(255)
        , FORMATTED VARCHAR(2000)
        , PLAIN VARCHAR(2000)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_RICH_TEXT_TP1 PRIMARY KEY(ID)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_RSTMT_RTYP_JN_OSUB_TYP
# -----------------------------------------------------------------------
drop table if exists KSST_RSTMT_RTYP_JN_OSUB_TYP
/

CREATE TABLE KSST_RSTMT_RTYP_JN_OSUB_TYP
(
      REF_STMT_REL_TYPE_ID VARCHAR(255) NOT NULL
        , OBJ_SUB_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSST_RSTMT_RTYP_JN_OSUBTYP_I1 (OBJ_SUB_TYPE_ID)
    , INDEX KSST_RSTMT_RTYP_JN_OSUBTYP_I2 (REF_STMT_REL_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_RSTMT_RTYP_JN_STMT_TYP
# -----------------------------------------------------------------------
drop table if exists KSST_RSTMT_RTYP_JN_STMT_TYP
/

CREATE TABLE KSST_RSTMT_RTYP_JN_STMT_TYP
(
      REF_STMT_REL_TYPE_ID VARCHAR(255) NOT NULL
        , STMT_TYPE_ID VARCHAR(255) NOT NULL
    


    , INDEX KSST_RSTMT_RTYP_JN_ST_TYP_I1 (REF_STMT_REL_TYPE_ID)
    , INDEX KSST_RSTMT_RTYP_JN_ST_TYP_I2 (STMT_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT
# -----------------------------------------------------------------------
drop table if exists KSST_STMT
/

CREATE TABLE KSST_STMT
(
      ID VARCHAR(255)
        , CREATEID VARCHAR(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR DECIMAL(19) NOT NULL
        , NAME VARCHAR(255)
        , OPERATOR VARCHAR(255)
        , ST VARCHAR(255)
        , RT_DESCR_ID VARCHAR(255)
        , STMT_TYPE_ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
    
    , CONSTRAINT KSST_STMTP1 PRIMARY KEY(ID)


    , INDEX KSST_STMT_I1 (STMT_TYPE_ID)
    , INDEX KSST_STMT_I2 (RT_DESCR_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_ATTR
/

CREATE TABLE KSST_STMT_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_STMT_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_STMT_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_JN_REQ_COM
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_JN_REQ_COM
/

CREATE TABLE KSST_STMT_JN_REQ_COM
(
      STMT_ID VARCHAR(255) NOT NULL
        , REQ_COM_ID VARCHAR(255) NOT NULL
    


    , INDEX KSST_STMT_JN_REQ_COM_I1 (STMT_ID)
    , INDEX KSST_STMT_JN_REQ_COM_I2 (REQ_COM_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_JN_STMT
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_JN_STMT
/

CREATE TABLE KSST_STMT_JN_STMT
(
      STMT_ID VARCHAR(255) NOT NULL
        , CHLD_STMT_ID VARCHAR(255) NOT NULL
    

    , CONSTRAINT SYS_C0011839 UNIQUE (CHLD_STMT_ID)

    , INDEX KSST_STMT_JN_STMT_I1 (STMT_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_TYPE
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_TYPE
/

CREATE TABLE KSST_STMT_TYPE
(
      TYPE_KEY VARCHAR(255)
        , TYPE_DESC VARCHAR(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_STMT_TYPEP1 PRIMARY KEY(TYPE_KEY)



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_TYPE_ATTR
/

CREATE TABLE KSST_STMT_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_STMT_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_STMT_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_TYP_JN_RC_TYP
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_TYP_JN_RC_TYP
/

CREATE TABLE KSST_STMT_TYP_JN_RC_TYP
(
      ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
        , REQ_COM_TYPE_ID VARCHAR(255)
        , SORT_ORDER DECIMAL(10)
        , STMT_TYPE_ID VARCHAR(255)
    
    , CONSTRAINT KSST_STMT_TYP_JN_RC_TYPP1 PRIMARY KEY(ID)


    , INDEX KSST_STMT_TYP_JN_RC_TYP_I1 (REQ_COM_TYPE_ID)
    , INDEX KSST_STMT_TYP_JN_RC_TYP_I2 (STMT_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_STMT_TYP_JN_STMT_TYP
# -----------------------------------------------------------------------
drop table if exists KSST_STMT_TYP_JN_STMT_TYP
/

CREATE TABLE KSST_STMT_TYP_JN_STMT_TYP
(
      ID VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
        , CHLD_STMT_TYPE_ID VARCHAR(255)
        , SORT_ORDER DECIMAL(10)
        , STMT_TYPE_ID VARCHAR(255)
    
    , CONSTRAINT KSST_STMT_TYP_JN_STMT_TYPP1 PRIMARY KEY(ID)


    , INDEX KSST_STMT_TYP_JN_STMT_TYP_I1 (CHLD_STMT_TYPE_ID)
    , INDEX KSST_STMT_TYP_JN_STMT_TYP_I2 (STMT_TYPE_ID)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KSST_USAGE_TYPE_ATTR
# -----------------------------------------------------------------------
drop table if exists KSST_USAGE_TYPE_ATTR
/

CREATE TABLE KSST_USAGE_TYPE_ATTR
(
      ID VARCHAR(255)
        , ATTR_NAME VARCHAR(255)
        , ATTR_VALUE VARCHAR(2000)
        , OWNER VARCHAR(255)
        , OBJ_ID VARCHAR(36)
        , VER_NBR DECIMAL(19)
    
    , CONSTRAINT KSST_USAGE_TYPE_ATTRP1 PRIMARY KEY(ID)


    , INDEX KSST_USAGE_TYPE_ATTR_I1 (OWNER)

) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KS_DB_VERSION
# -----------------------------------------------------------------------
drop table if exists KS_DB_VERSION
/

CREATE TABLE KS_DB_VERSION
(
      VERSION VARCHAR(255)
        , MODULE_NAME VARCHAR(255)
        , UPGRADE_TIME TIMESTAMP
        , BUILD_ID VARCHAR(255)
        , BUILD_TIMESTAMP VARCHAR(255)
    



) ENGINE InnoDB CHARACTER SET utf8 COLLATE utf8_bin
/


# -----------------------------------------------------------------------
# KRIM_GRP_MBR_V
# -----------------------------------------------------------------------
drop view if exists KRIM_GRP_MBR_V
/
CREATE VIEW KRIM_GRP_MBR_V AS 
SELECT g.NMSPC_CD
, g.grp_nm
, g.GRP_ID
, p.PRNCPL_NM
, p.PRNCPL_ID
, mg.GRP_NM AS mbr_grp_nm
, mg.GRP_ID AS mbr_grp_id
FROM KRIM_GRP_MBR_T gm
LEFT JOIN krim_grp_t g
ON g.GRP_ID = gm.GRP_ID
LEFT OUTER JOIN krim_grp_t mg
ON mg.GRP_ID = gm.MBR_ID
AND gm.MBR_TYP_CD = 'G'
LEFT OUTER JOIN krim_prncpl_t p
ON p.PRNCPL_ID = gm.MBR_ID
AND gm.MBR_TYP_CD = 'P'
LEFT OUTER JOIN krim_entity_nm_t en
ON en.ENTITY_ID = p.ENTITY_ID
AND en.DFLT_IND = 'Y'
AND en.ACTV_IND = 'Y'
ORDER BY nmspc_cd, grp_nm, prncpl_nm




/


# -----------------------------------------------------------------------
# KRIM_GRP_V
# -----------------------------------------------------------------------
drop view if exists KRIM_GRP_V
/
CREATE VIEW KRIM_GRP_V AS 
SELECT g.NMSPC_CD
, g.grp_nm
, g.GRP_ID
, t.NM AS grp_typ_nm
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM krim_grp_t g
LEFT OUTER JOIN KRIM_GRP_ATTR_DATA_T d
ON d.grp_id = g.GRP_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_TYP_T t
ON g.KIM_TYP_ID = t.KIM_TYP_ID




/


# -----------------------------------------------------------------------
# KRIM_PERM_ATTR_V
# -----------------------------------------------------------------------
drop view if exists KRIM_PERM_ATTR_V
/
CREATE VIEW KRIM_PERM_ATTR_V AS 
SELECT
t.nmspc_cd AS tmpl_nmspc_cd
, t.NM AS tmpl_nm
, t.PERM_TMPL_ID
, p.nmspc_cd AS perm_nmspc_cd
, p.NM AS perm_nm
, p.PERM_ID
, a.NM AS attr_nm
, ad.ATTR_VAL AS attr_val
FROM KRIM_PERM_T p
LEFT JOIN KRIM_PERM_TMPL_T t
ON p.PERM_TMPL_ID = t.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_PERM_ATTR_DATA_T ad
ON p.PERM_ID = ad.perm_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON ad.KIM_ATTR_DEFN_ID = a.KIM_ATTR_DEFN_ID
ORDER BY tmpl_nmspc_cd, tmpl_nm, perm_nmspc_cd, perm_id, attr_nm




/


# -----------------------------------------------------------------------
# KRIM_PERM_V
# -----------------------------------------------------------------------
drop view if exists KRIM_PERM_V
/
CREATE VIEW KRIM_PERM_V AS 
SELECT
t.nmspc_cd AS tmpl_nmspc_cd
, t.NM AS tmpl_nm
, t.PERM_TMPL_ID
, p.nmspc_cd AS perm_nmspc_cd
, p.NM AS perm_nm
, p.PERM_ID
, typ.NM AS perm_typ_nm
, typ.SRVC_NM
FROM KRIM_PERM_T p
INNER JOIN KRIM_PERM_TMPL_T t
ON p.PERM_TMPL_ID = t.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_TYP_T typ
ON t.KIM_TYP_ID = typ.KIM_TYP_ID




/


# -----------------------------------------------------------------------
# KRIM_PRNCPL_V
# -----------------------------------------------------------------------
drop view if exists KRIM_PRNCPL_V
/
CREATE VIEW KRIM_PRNCPL_V AS 
SELECT
p.PRNCPL_ID
,p.PRNCPL_NM
,en.FIRST_NM
,en.LAST_NM
,ea.AFLTN_TYP_CD
,ea.CAMPUS_CD
,eei.EMP_STAT_CD
,eei.EMP_TYP_CD
FROM krim_prncpl_t p
LEFT OUTER JOIN krim_entity_emp_info_t eei
ON eei.ENTITY_ID = p.ENTITY_ID
LEFT OUTER JOIN krim_entity_afltn_t ea
ON ea.ENTITY_ID = p.ENTITY_ID
LEFT OUTER JOIN krim_entity_nm_t en
ON p.ENTITY_ID = en.ENTITY_ID
AND 'Y' = en.DFLT_IND




/


# -----------------------------------------------------------------------
# KRIM_ROLE_GRP_V
# -----------------------------------------------------------------------
drop view if exists KRIM_ROLE_GRP_V
/
CREATE VIEW KRIM_ROLE_GRP_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, g.NMSPC_CD AS grp_nmspc_cd
, g.GRP_NM
, rm.ROLE_MBR_ID
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM KRIM_ROLE_MBR_T rm
LEFT JOIN KRIM_ROLE_T r
ON r.ROLE_ID = rm.ROLE_ID
LEFT JOIN KRIM_GRP_T g
ON g.GRP_ID = rm.MBR_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T d
ON d.role_mbr_id = rm.ROLE_MBR_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
WHERE rm.MBR_TYP_CD = 'G'
ORDER BY nmspc_cd, role_nm, grp_nmspc_cd, grp_nm, role_mbr_id, attr_nm




/


# -----------------------------------------------------------------------
# KRIM_ROLE_PERM_V
# -----------------------------------------------------------------------
drop view if exists KRIM_ROLE_PERM_V
/
CREATE VIEW KRIM_ROLE_PERM_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, pt.NMSPC_CD AS tmpl_nmspc_cd
, pt.NM AS tmpl_nm
, pt.PERM_TMPL_ID
, p.NMSPC_CD AS perm_nmpsc_cd
, p.NM AS perm_nm
, p.PERM_ID
, a.NM AS attr_nm
, ad.ATTR_VAL AS attr_val
FROM KRIM_PERM_T p
LEFT JOIN KRIM_PERM_TMPL_T pt
ON p.PERM_TMPL_ID = pt.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_PERM_ATTR_DATA_T ad
ON p.PERM_ID = ad.perm_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON ad.KIM_ATTR_DEFN_ID = a.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_ROLE_PERM_T rp
ON rp.PERM_ID = p.PERM_ID
LEFT OUTER JOIN KRIM_ROLE_T r
ON rp.ROLE_ID = r.ROLE_ID
ORDER BY NMSPC_CD, role_nm, tmpl_nmspc_cd, tmpl_nm, perm_id, attr_nm




/


# -----------------------------------------------------------------------
# KRIM_ROLE_PRNCPL_V
# -----------------------------------------------------------------------
drop view if exists KRIM_ROLE_PRNCPL_V
/
CREATE VIEW KRIM_ROLE_PRNCPL_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.ROLE_ID
, p.PRNCPL_NM
, p.PRNCPL_ID
, en.FIRST_NM
, en.LAST_NM
, rm.ROLE_MBR_ID
, ad.NM AS attr_nm
, rmad.ATTR_VAL AS attr_val
FROM KRIM_ROLE_T r
LEFT OUTER JOIN KRIM_ROLE_MBR_T rm
ON r.ROLE_ID = rm.ROLE_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T rmad
ON rm.ROLE_MBR_ID = rmad.role_mbr_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T ad
ON rmad.KIM_ATTR_DEFN_ID = ad.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_PRNCPL_T p
ON rm.MBR_ID = p.PRNCPL_ID
AND rm.mbr_typ_cd = 'P'
LEFT OUTER JOIN KRIM_ENTITY_NM_T en
ON p.ENTITY_ID = en.ENTITY_ID
WHERE (en.DFLT_IND = 'Y')
ORDER BY nmspc_cd, role_nm, prncpl_nm, rm.ROLE_MBR_ID, attr_nm




/


# -----------------------------------------------------------------------
# KRIM_ROLE_ROLE_V
# -----------------------------------------------------------------------
drop view if exists KRIM_ROLE_ROLE_V
/
CREATE VIEW KRIM_ROLE_ROLE_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, mr.NMSPC_CD AS mbr_role_nmspc_cd
, mr.role_NM AS mbr_role_nm
, mr.role_id AS mbr_role_id
, rm.role_mbr_id
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM KRIM_ROLE_MBR_T rm
LEFT JOIN KRIM_ROLE_T r
ON r.ROLE_ID = rm.ROLE_ID
LEFT JOIN KRIM_role_T mr
ON mr.role_ID = rm.MBR_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T d
ON d.role_mbr_id = rm.ROLE_MBR_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
WHERE rm.MBR_TYP_CD = 'R'
ORDER BY nmspc_cd, role_nm, mbr_role_nmspc_cd, mbr_role_nm, role_mbr_id, attr_nm




/


# -----------------------------------------------------------------------
# KRIM_ROLE_V
# -----------------------------------------------------------------------
drop view if exists KRIM_ROLE_V
/
CREATE VIEW KRIM_ROLE_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.ROLE_ID
, t.nm AS role_typ_nm
, t.SRVC_NM
, t.KIM_TYP_ID
FROM KRIM_ROLE_T r
, KRIM_TYP_T t
WHERE t.KIM_TYP_ID = r.KIM_TYP_ID
AND r.ACTV_IND = 'Y'
ORDER BY nmspc_cd
, role_nm




/


# -----------------------------------------------------------------------
# KRIM_RSP_ATTR_V
# -----------------------------------------------------------------------
drop view if exists KRIM_RSP_ATTR_V
/
CREATE VIEW KRIM_RSP_ATTR_V AS 
SELECT
krim_typ_t.NM AS responsibility_type_name
, KRIM_rsp_TMPL_T.NM AS rsp_TEMPLATE_NAME
, KRIM_rsp_T.nmspc_cd AS rsp_namespace_code
, KRIM_rsp_T.NM AS rsp_NAME
, krim_rsp_t.RSP_ID AS rsp_id
, KRIM_ATTR_DEFN_T.NM AS attribute_name
, KRIM_rsp_ATTR_DATA_T.ATTR_VAL AS attribute_value
FROM KRIM_rsp_T KRIM_rsp_T
INNER JOIN KRIM_rsp_ATTR_DATA_T KRIM_rsp_ATTR_DATA_T
ON KRIM_rsp_T.rsp_ID = KRIM_rsp_ATTR_DATA_T.rsp_id
INNER JOIN KRIM_ATTR_DEFN_T KRIM_ATTR_DEFN_T
ON KRIM_rsp_ATTR_DATA_T.KIM_ATTR_DEFN_ID = KRIM_ATTR_DEFN_T.KIM_ATTR_DEFN_ID
INNER JOIN KRIM_rsp_TMPL_T KRIM_rsp_TMPL_T
ON KRIM_rsp_T.rsp_TMPL_ID = KRIM_rsp_TMPL_T.rsp_TMPL_ID
INNER JOIN KRIM_TYP_T KRIM_TYP_T
ON KRIM_rsp_TMPL_T.KIM_TYP_ID = KRIM_TYP_T.KIM_TYP_ID
ORDER BY rsp_TEMPLATE_NAME, rsp_NAME, attribute_name




/


# -----------------------------------------------------------------------
# KRIM_RSP_ROLE_ACTN_V
# -----------------------------------------------------------------------
drop view if exists KRIM_RSP_ROLE_ACTN_V
/
CREATE VIEW KRIM_RSP_ROLE_ACTN_V AS 
select
rsp.nmspc_cd as rsp_nmspc_cd
, rsp.rsp_id
, r.NMSPC_CD
, r.ROLE_NM
, rr.ROLE_ID
, rm.MBR_ID
, rm.MBR_TYP_CD
, rm.ROLE_MBR_ID
, actn.ACTN_TYP_CD
, actn.ACTN_PLCY_CD
, actn.FRC_ACTN
, actn.PRIORITY_NBR
from krim_rsp_t rsp
left join krim_rsp_tmpl_t rspt
on rsp.rsp_tmpl_id = rspt.rsp_tmpl_id
left outer join krim_role_rsp_t rr
on rr.rsp_id = rsp.rsp_id
left outer join KRIM_ROLE_MBR_T rm
ON rm.ROLE_ID = rr.ROLE_ID
left outer join KRIM_ROLE_RSP_ACTN_T actn
ON actn.ROLE_RSP_ID = rr.ROLE_RSP_ID
AND (actn.ROLE_MBR_ID = rm.ROLE_MBR_ID OR actn.ROLE_MBR_ID = '*')
left outer join krim_role_t r
on rr.role_id = r.role_id
order by rsp_nmspc_cd
, rsp_id
, role_id
, role_mbr_id




/


# -----------------------------------------------------------------------
# KRIM_RSP_ROLE_V
# -----------------------------------------------------------------------
drop view if exists KRIM_RSP_ROLE_V
/
CREATE VIEW KRIM_RSP_ROLE_V AS 
select
rspt.nmspc_cd as rsp_tmpl_nmspc_cd
, rspt.nm as rsp_tmpl_nm
, rsp.nmspc_cd as rsp_nmspc_cd
, rsp.nm as rsp_nm
, rsp.rsp_id
, a.nm as attr_nm
, d.attr_val
, r.NMSPC_CD
, r.ROLE_NM
, rr.ROLE_ID
from krim_rsp_t rsp
left join krim_rsp_tmpl_t rspt
on rsp.rsp_tmpl_id = rspt.rsp_tmpl_id
left outer join krim_rsp_attr_data_t d
on rsp.rsp_id = d.rsp_id
left outer join krim_attr_defn_t a
on d.kim_attr_defn_id = a.kim_attr_defn_id
left outer join krim_role_rsp_t rr
on rr.rsp_id = rsp.rsp_id
left outer join krim_role_t r
on rr.role_id = r.role_id
order by rsp_tmpl_nmspc_cd, rsp_tmpl_nm, rsp_nmspc_cd, rsp_nm, rsp_id, attr_nm, attr_val




/


# -----------------------------------------------------------------------
# KREN_CHNL_S
# -----------------------------------------------------------------------
drop table if exists KREN_CHNL_S
/

CREATE TABLE KREN_CHNL_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_CHNL_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_CHNL_SUBSCRP_S
# -----------------------------------------------------------------------
drop table if exists KREN_CHNL_SUBSCRP_S
/

CREATE TABLE KREN_CHNL_SUBSCRP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_CHNL_SUBSCRP_S auto_increment = 1020
/

# -----------------------------------------------------------------------
# KREN_CNTNT_TYP_S
# -----------------------------------------------------------------------
drop table if exists KREN_CNTNT_TYP_S
/

CREATE TABLE KREN_CNTNT_TYP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_CNTNT_TYP_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_MSG_DELIV_S
# -----------------------------------------------------------------------
drop table if exists KREN_MSG_DELIV_S
/

CREATE TABLE KREN_MSG_DELIV_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_MSG_DELIV_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_MSG_S
# -----------------------------------------------------------------------
drop table if exists KREN_MSG_S
/

CREATE TABLE KREN_MSG_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_MSG_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_NTFCTN_MSG_DELIV_S
# -----------------------------------------------------------------------
drop table if exists KREN_NTFCTN_MSG_DELIV_S
/

CREATE TABLE KREN_NTFCTN_MSG_DELIV_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_NTFCTN_MSG_DELIV_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_NTFCTN_S
# -----------------------------------------------------------------------
drop table if exists KREN_NTFCTN_S
/

CREATE TABLE KREN_NTFCTN_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_NTFCTN_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_PRIO_S
# -----------------------------------------------------------------------
drop table if exists KREN_PRIO_S
/

CREATE TABLE KREN_PRIO_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_PRIO_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_PRODCR_S
# -----------------------------------------------------------------------
drop table if exists KREN_PRODCR_S
/

CREATE TABLE KREN_PRODCR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_PRODCR_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_RECIP_DELIV_S
# -----------------------------------------------------------------------
drop table if exists KREN_RECIP_DELIV_S
/

CREATE TABLE KREN_RECIP_DELIV_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_RECIP_DELIV_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_RECIP_LIST_S
# -----------------------------------------------------------------------
drop table if exists KREN_RECIP_LIST_S
/

CREATE TABLE KREN_RECIP_LIST_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_RECIP_LIST_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_RECIP_PREF_S
# -----------------------------------------------------------------------
drop table if exists KREN_RECIP_PREF_S
/

CREATE TABLE KREN_RECIP_PREF_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_RECIP_PREF_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_RECIP_S
# -----------------------------------------------------------------------
drop table if exists KREN_RECIP_S
/

CREATE TABLE KREN_RECIP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_RECIP_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_RVWER_S
# -----------------------------------------------------------------------
drop table if exists KREN_RVWER_S
/

CREATE TABLE KREN_RVWER_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_RVWER_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREN_SNDR_S
# -----------------------------------------------------------------------
drop table if exists KREN_SNDR_S
/

CREATE TABLE KREN_SNDR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREN_SNDR_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREW_ACTN_ITM_S
# -----------------------------------------------------------------------
drop table if exists KREW_ACTN_ITM_S
/

CREATE TABLE KREW_ACTN_ITM_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_ACTN_ITM_S auto_increment = 10320
/

# -----------------------------------------------------------------------
# KREW_ACTN_LIST_OPTN_S
# -----------------------------------------------------------------------
drop table if exists KREW_ACTN_LIST_OPTN_S
/

CREATE TABLE KREW_ACTN_LIST_OPTN_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_ACTN_LIST_OPTN_S auto_increment = 1373
/

# -----------------------------------------------------------------------
# KREW_ACTN_RQST_S
# -----------------------------------------------------------------------
drop table if exists KREW_ACTN_RQST_S
/

CREATE TABLE KREW_ACTN_RQST_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_ACTN_RQST_S auto_increment = 2465
/

# -----------------------------------------------------------------------
# KREW_ACTN_TKN_S
# -----------------------------------------------------------------------
drop table if exists KREW_ACTN_TKN_S
/

CREATE TABLE KREW_ACTN_TKN_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_ACTN_TKN_S auto_increment = 2389
/

# -----------------------------------------------------------------------
# KREW_DOC_HDR_S
# -----------------------------------------------------------------------
drop table if exists KREW_DOC_HDR_S
/

CREATE TABLE KREW_DOC_HDR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_DOC_HDR_S auto_increment = 3115
/

# -----------------------------------------------------------------------
# KREW_DOC_LNK_S
# -----------------------------------------------------------------------
drop table if exists KREW_DOC_LNK_S
/

CREATE TABLE KREW_DOC_LNK_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_DOC_LNK_S auto_increment = 2000
/

# -----------------------------------------------------------------------
# KREW_DOC_NTE_S
# -----------------------------------------------------------------------
drop table if exists KREW_DOC_NTE_S
/

CREATE TABLE KREW_DOC_NTE_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_DOC_NTE_S auto_increment = 2020
/

# -----------------------------------------------------------------------
# KREW_DOC_TYP_ATTR_S
# -----------------------------------------------------------------------
drop table if exists KREW_DOC_TYP_ATTR_S
/

CREATE TABLE KREW_DOC_TYP_ATTR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_DOC_TYP_ATTR_S auto_increment = 2016
/

# -----------------------------------------------------------------------
# KREW_EDL_FLD_DMP_S
# -----------------------------------------------------------------------
drop table if exists KREW_EDL_FLD_DMP_S
/

CREATE TABLE KREW_EDL_FLD_DMP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_EDL_FLD_DMP_S auto_increment = 5000
/

# -----------------------------------------------------------------------
# KREW_EDL_S
# -----------------------------------------------------------------------
drop table if exists KREW_EDL_S
/

CREATE TABLE KREW_EDL_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_EDL_S auto_increment = 2020
/

# -----------------------------------------------------------------------
# KREW_HLP_S
# -----------------------------------------------------------------------
drop table if exists KREW_HLP_S
/

CREATE TABLE KREW_HLP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_HLP_S auto_increment = 100
/

# -----------------------------------------------------------------------
# KREW_OUT_BOX_ITM_S
# -----------------------------------------------------------------------
drop table if exists KREW_OUT_BOX_ITM_S
/

CREATE TABLE KREW_OUT_BOX_ITM_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_OUT_BOX_ITM_S auto_increment = 10051
/

# -----------------------------------------------------------------------
# KREW_RIA_DOCTYPE_MAP_ID_S
# -----------------------------------------------------------------------
drop table if exists KREW_RIA_DOCTYPE_MAP_ID_S
/

CREATE TABLE KREW_RIA_DOCTYPE_MAP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RIA_DOCTYPE_MAP_ID_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KREW_RSP_S
# -----------------------------------------------------------------------
drop table if exists KREW_RSP_S
/

CREATE TABLE KREW_RSP_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RSP_S auto_increment = 2065
/

# -----------------------------------------------------------------------
# KREW_RTE_NODE_CFG_PARM_S
# -----------------------------------------------------------------------
drop table if exists KREW_RTE_NODE_CFG_PARM_S
/

CREATE TABLE KREW_RTE_NODE_CFG_PARM_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RTE_NODE_CFG_PARM_S auto_increment = 3363
/

# -----------------------------------------------------------------------
# KREW_RTE_NODE_S
# -----------------------------------------------------------------------
drop table if exists KREW_RTE_NODE_S
/

CREATE TABLE KREW_RTE_NODE_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RTE_NODE_S auto_increment = 3317
/

# -----------------------------------------------------------------------
# KREW_RTE_TMPL_S
# -----------------------------------------------------------------------
drop table if exists KREW_RTE_TMPL_S
/

CREATE TABLE KREW_RTE_TMPL_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RTE_TMPL_S auto_increment = 1645
/

# -----------------------------------------------------------------------
# KREW_RULE_EXPR_S
# -----------------------------------------------------------------------
drop table if exists KREW_RULE_EXPR_S
/

CREATE TABLE KREW_RULE_EXPR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RULE_EXPR_S auto_increment = 2002
/

# -----------------------------------------------------------------------
# KREW_RULE_TMPL_OPTN_S
# -----------------------------------------------------------------------
drop table if exists KREW_RULE_TMPL_OPTN_S
/

CREATE TABLE KREW_RULE_TMPL_OPTN_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_RULE_TMPL_OPTN_S auto_increment = 2020
/

# -----------------------------------------------------------------------
# KREW_SRCH_ATTR_S
# -----------------------------------------------------------------------
drop table if exists KREW_SRCH_ATTR_S
/

CREATE TABLE KREW_SRCH_ATTR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_SRCH_ATTR_S auto_increment = 2188
/

# -----------------------------------------------------------------------
# KREW_USR_S
# -----------------------------------------------------------------------
drop table if exists KREW_USR_S
/

CREATE TABLE KREW_USR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KREW_USR_S auto_increment = 100000000000
/

# -----------------------------------------------------------------------
# KRIM_ATTR_DATA_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ATTR_DATA_ID_S
/

CREATE TABLE KRIM_ATTR_DATA_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ATTR_DATA_ID_S auto_increment = 10012
/

# -----------------------------------------------------------------------
# KRIM_ATTR_DEFN_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ATTR_DEFN_ID_S
/

CREATE TABLE KRIM_ATTR_DEFN_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ATTR_DEFN_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_DLGN_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_DLGN_ID_S
/

CREATE TABLE KRIM_DLGN_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_DLGN_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_DLGN_MBR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_DLGN_MBR_ID_S
/

CREATE TABLE KRIM_DLGN_MBR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_DLGN_MBR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_ADDR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_ADDR_ID_S
/

CREATE TABLE KRIM_ENTITY_ADDR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_ADDR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_AFLTN_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_AFLTN_ID_S
/

CREATE TABLE KRIM_ENTITY_AFLTN_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_AFLTN_ID_S auto_increment = 10011
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_CTZNSHP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_CTZNSHP_ID_S
/

CREATE TABLE KRIM_ENTITY_CTZNSHP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_CTZNSHP_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_EMAIL_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_EMAIL_ID_S
/

CREATE TABLE KRIM_ENTITY_EMAIL_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_EMAIL_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_EMP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_EMP_ID_S
/

CREATE TABLE KRIM_ENTITY_EMP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_EMP_ID_S auto_increment = 10011
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_ETHNIC_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_ETHNIC_ID_S
/

CREATE TABLE KRIM_ENTITY_ETHNIC_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_ETHNIC_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_EXT_ID_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_EXT_ID_ID_S
/

CREATE TABLE KRIM_ENTITY_EXT_ID_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_EXT_ID_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_ID_S
/

CREATE TABLE KRIM_ENTITY_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_ID_S auto_increment = 10008
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_NM_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_NM_ID_S
/

CREATE TABLE KRIM_ENTITY_NM_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_NM_ID_S auto_increment = 10008
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_PHONE_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_PHONE_ID_S
/

CREATE TABLE KRIM_ENTITY_PHONE_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_PHONE_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_RESIDENCY_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_RESIDENCY_ID_S
/

CREATE TABLE KRIM_ENTITY_RESIDENCY_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_RESIDENCY_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ENTITY_VISA_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ENTITY_VISA_ID_S
/

CREATE TABLE KRIM_ENTITY_VISA_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ENTITY_VISA_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_GRP_ATTR_DATA_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_GRP_ATTR_DATA_ID_S
/

CREATE TABLE KRIM_GRP_ATTR_DATA_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_GRP_ATTR_DATA_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_GRP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_GRP_ID_S
/

CREATE TABLE KRIM_GRP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_GRP_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_GRP_MBR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_GRP_MBR_ID_S
/

CREATE TABLE KRIM_GRP_MBR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_GRP_MBR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_PERM_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_PERM_ID_S
/

CREATE TABLE KRIM_PERM_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_PERM_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_PERM_RQRD_ATTR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_PERM_RQRD_ATTR_ID_S
/

CREATE TABLE KRIM_PERM_RQRD_ATTR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_PERM_RQRD_ATTR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_PERM_TMPL_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_PERM_TMPL_ID_S
/

CREATE TABLE KRIM_PERM_TMPL_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_PERM_TMPL_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_PRNCPL_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_PRNCPL_ID_S
/

CREATE TABLE KRIM_PRNCPL_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_PRNCPL_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ROLE_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ROLE_ID_S
/

CREATE TABLE KRIM_ROLE_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ROLE_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ROLE_MBR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ROLE_MBR_ID_S
/

CREATE TABLE KRIM_ROLE_MBR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ROLE_MBR_ID_S auto_increment = 10002
/

# -----------------------------------------------------------------------
# KRIM_ROLE_PERM_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ROLE_PERM_ID_S
/

CREATE TABLE KRIM_ROLE_PERM_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ROLE_PERM_ID_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KRIM_ROLE_RSP_ACTN_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ROLE_RSP_ACTN_ID_S
/

CREATE TABLE KRIM_ROLE_RSP_ACTN_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ROLE_RSP_ACTN_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_ROLE_RSP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_ROLE_RSP_ID_S
/

CREATE TABLE KRIM_ROLE_RSP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_ROLE_RSP_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_RSP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_RSP_ID_S
/

CREATE TABLE KRIM_RSP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_RSP_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_RSP_RQRD_ATTR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_RSP_RQRD_ATTR_ID_S
/

CREATE TABLE KRIM_RSP_RQRD_ATTR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_RSP_RQRD_ATTR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_RSP_TMPL_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_RSP_TMPL_ID_S
/

CREATE TABLE KRIM_RSP_TMPL_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_RSP_TMPL_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_TYP_ATTR_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_TYP_ATTR_ID_S
/

CREATE TABLE KRIM_TYP_ATTR_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_TYP_ATTR_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRIM_TYP_ID_S
# -----------------------------------------------------------------------
drop table if exists KRIM_TYP_ID_S
/

CREATE TABLE KRIM_TYP_ID_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRIM_TYP_ID_S auto_increment = 10000
/

# -----------------------------------------------------------------------
# KRNS_DOC_TYP_ATTR_S
# -----------------------------------------------------------------------
drop table if exists KRNS_DOC_TYP_ATTR_S
/

CREATE TABLE KRNS_DOC_TYP_ATTR_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRNS_DOC_TYP_ATTR_S auto_increment = 1000
/

# -----------------------------------------------------------------------
# KRNS_LOCK_S
# -----------------------------------------------------------------------
drop table if exists KRNS_LOCK_S
/

CREATE TABLE KRNS_LOCK_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRNS_LOCK_S auto_increment = 2000
/

# -----------------------------------------------------------------------
# KRNS_LOOKUP_RSLT_S
# -----------------------------------------------------------------------
drop table if exists KRNS_LOOKUP_RSLT_S
/

CREATE TABLE KRNS_LOOKUP_RSLT_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRNS_LOOKUP_RSLT_S auto_increment = 2000
/

# -----------------------------------------------------------------------
# KRNS_MAINT_LOCK_S
# -----------------------------------------------------------------------
drop table if exists KRNS_MAINT_LOCK_S
/

CREATE TABLE KRNS_MAINT_LOCK_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRNS_MAINT_LOCK_S auto_increment = 2020
/

# -----------------------------------------------------------------------
# KRNS_NTE_S
# -----------------------------------------------------------------------
drop table if exists KRNS_NTE_S
/

CREATE TABLE KRNS_NTE_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRNS_NTE_S auto_increment = 2020
/

# -----------------------------------------------------------------------
# KRSB_BAM_PARM_S
# -----------------------------------------------------------------------
drop table if exists KRSB_BAM_PARM_S
/

CREATE TABLE KRSB_BAM_PARM_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRSB_BAM_PARM_S auto_increment = 2000
/

# -----------------------------------------------------------------------
# KRSB_BAM_S
# -----------------------------------------------------------------------
drop table if exists KRSB_BAM_S
/

CREATE TABLE KRSB_BAM_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRSB_BAM_S auto_increment = 2000
/

# -----------------------------------------------------------------------
# KRSB_FLT_SVC_DEF_S
# -----------------------------------------------------------------------
drop table if exists KRSB_FLT_SVC_DEF_S
/

CREATE TABLE KRSB_FLT_SVC_DEF_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRSB_FLT_SVC_DEF_S auto_increment = 1325
/

# -----------------------------------------------------------------------
# KRSB_MSG_QUE_S
# -----------------------------------------------------------------------
drop table if exists KRSB_MSG_QUE_S
/

CREATE TABLE KRSB_MSG_QUE_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRSB_MSG_QUE_S auto_increment = 2781
/

# -----------------------------------------------------------------------
# KRSB_SVC_DEF_S
# -----------------------------------------------------------------------
drop table if exists KRSB_SVC_DEF_S
/

CREATE TABLE KRSB_SVC_DEF_S
(
	id bigint(19) not null auto_increment, primary key (id) 
) ENGINE MyISAM
/
ALTER TABLE KRSB_SVC_DEF_S auto_increment = 1441
/
